@@ -10,8 +10,10 @@ import sys
 from scipy.spatial.distance import cdist, pdist
 from matplotlib import rcParams
 import matplotlib.pyplot as plt
+from itertools import combinations
+from itertools import combinations_with_replacement
 from plotnine import *
-
+labmodule = __import__(__name__)
 def ReadPDBintoDataFrame(PDBfileNameString):
     DataFrame = pandas.DataFrame(PandasPdb().read_pdb(PDBfileNameString).df["ATOM"])
     file = open(PDBfileNameString,'r')
@@ -351,4 +353,12 @@ def FindPotentialClashes(PDBDataFrame, Atom1Name, Atom2Name, DistanceLimit):
     Distances = Distances[Distances < DistanceLimit]
     Histogram = plt.hist(Distances)
     plt.xlabel(Atom1Name+  "-"+ Atom2Name +  " Distances up to " +str(DistanceLimit) + " angstroms")
-    return Histogram, pandas.DataFrame(Distances)
\ No newline at end of file
+    return Histogram, pandas.DataFrame(Distances)
+def CheckAllPotentialClashes(PDBDataFrame):
+    distances = [2.4, 2.9, 2.9, 2.75, 3.4,3.22, 3.25, 3.04, 3.07, 3.1]
+    for count, clash in enumerate(list(combinations_with_replacement("HCON", 2))):
+        FindPotentialClashes(PDBDataFrame, clash[0], clash[1], distances[count])
+        plt.show()
+def FindParavastuFunction(SearchString):
+    paravastu_functions = dir(labmodule)
+    return [item for item in paravastu_functions if item.find(SearchString)>-1]
